# Generated by Django 5.0.2 on 2024-03-08 11:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0009_remove_default_domain_default_domain'),
    ]

    operations = [
        migrations.AlterField(
            model_name='domains',
            name='Description',
            field=models.CharField(default=None, max_length=50),
        ),
    ]
