# Generated by Django 5.0.2 on 2024-02-12 05:59

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0005_remove_domains_default'),
    ]

    operations = [
        migrations.AddField(
            model_name='default_domain',
            name='default_domain',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='default_domain',
            name='domain',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to='sites.domains'),
        ),
    ]
