# Generated by Django 5.0.2 on 2024-02-12 06:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0006_default_domain_default_domain_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='default_domain',
            name='default_domain',
            field=models.BooleanField(),
        ),
    ]
