# Generated by Django 5.0.2 on 2024-02-12 07:58

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0008_domains_primary_domain'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='default_domain',
            name='default_domain',
        ),
    ]
